/****************************************************************************
** Meta object code from reading C++ file 'klauncher.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kinit-5.39.0/src/klauncher/klauncher.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'klauncher.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KLauncher_t {
    QByteArrayData data[23];
    char stringdata0[284];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KLauncher_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KLauncher_t qt_meta_stringdata_KLauncher = {
    {
QT_MOC_LITERAL(0, 0, 9), // "KLauncher"
QT_MOC_LITERAL(1, 10, 14), // "autoStart0Done"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 14), // "autoStart1Done"
QT_MOC_LITERAL(4, 41, 14), // "autoStart2Done"
QT_MOC_LITERAL(5, 56, 8), // "destruct"
QT_MOC_LITERAL(6, 65, 13), // "slotAutoStart"
QT_MOC_LITERAL(7, 79, 11), // "slotDequeue"
QT_MOC_LITERAL(8, 91, 15), // "slotKDEInitData"
QT_MOC_LITERAL(9, 107, 20), // "slotNameOwnerChanged"
QT_MOC_LITERAL(10, 128, 4), // "name"
QT_MOC_LITERAL(11, 133, 8), // "oldOnwer"
QT_MOC_LITERAL(12, 142, 8), // "newOwner"
QT_MOC_LITERAL(13, 151, 15), // "slotSlaveStatus"
QT_MOC_LITERAL(14, 167, 10), // "IdleSlave*"
QT_MOC_LITERAL(15, 178, 11), // "acceptSlave"
QT_MOC_LITERAL(16, 190, 13), // "slotSlaveGone"
QT_MOC_LITERAL(17, 204, 11), // "idleTimeout"
QT_MOC_LITERAL(18, 216, 13), // "slotGotOutput"
QT_MOC_LITERAL(19, 230, 12), // "slotFinished"
QT_MOC_LITERAL(20, 243, 8), // "exitCode"
QT_MOC_LITERAL(21, 252, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(22, 273, 10) // "exitStatus"

    },
    "KLauncher\0autoStart0Done\0\0autoStart1Done\0"
    "autoStart2Done\0destruct\0slotAutoStart\0"
    "slotDequeue\0slotKDEInitData\0"
    "slotNameOwnerChanged\0name\0oldOnwer\0"
    "newOwner\0slotSlaveStatus\0IdleSlave*\0"
    "acceptSlave\0slotSlaveGone\0idleTimeout\0"
    "slotGotOutput\0slotFinished\0exitCode\0"
    "QProcess::ExitStatus\0exitStatus"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KLauncher[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   84,    2, 0x06 /* Public */,
       3,    0,   85,    2, 0x06 /* Public */,
       4,    0,   86,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   87,    2, 0x0a /* Public */,
       6,    0,   88,    2, 0x0a /* Public */,
       7,    0,   89,    2, 0x0a /* Public */,
       8,    1,   90,    2, 0x0a /* Public */,
       9,    3,   93,    2, 0x0a /* Public */,
      13,    1,  100,    2, 0x0a /* Public */,
      15,    0,  103,    2, 0x0a /* Public */,
      16,    0,  104,    2, 0x0a /* Public */,
      17,    0,  105,    2, 0x0a /* Public */,
      18,    0,  106,    2, 0x09 /* Protected */,
      19,    2,  107,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,   10,   11,   12,
    QMetaType::Void, 0x80000000 | 14,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 21,   20,   22,

       0        // eod
};

void KLauncher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KLauncher *_t = static_cast<KLauncher *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->autoStart0Done(); break;
        case 1: _t->autoStart1Done(); break;
        case 2: _t->autoStart2Done(); break;
        case 3: _t->destruct(); break;
        case 4: _t->slotAutoStart(); break;
        case 5: _t->slotDequeue(); break;
        case 6: _t->slotKDEInitData((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->slotNameOwnerChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 8: _t->slotSlaveStatus((*reinterpret_cast< IdleSlave*(*)>(_a[1]))); break;
        case 9: _t->acceptSlave(); break;
        case 10: _t->slotSlaveGone(); break;
        case 11: _t->idleTimeout(); break;
        case 12: _t->slotGotOutput(); break;
        case 13: _t->slotFinished((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdleSlave* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KLauncher::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLauncher::autoStart0Done)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KLauncher::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLauncher::autoStart1Done)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KLauncher::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLauncher::autoStart2Done)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KLauncher::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KLauncher.data,
      qt_meta_data_KLauncher,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KLauncher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KLauncher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KLauncher.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int KLauncher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void KLauncher::autoStart0Done()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KLauncher::autoStart1Done()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KLauncher::autoStart2Done()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
