/****************************************************************************
** Meta object code from reading C++ file 'klauncher_adaptor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kinit-5.39.0/src/klauncher/klauncher_adaptor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'klauncher_adaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KLauncherAdaptor_t {
    QByteArrayData data[37];
    char stringdata0[430];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KLauncherAdaptor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KLauncherAdaptor_t qt_meta_stringdata_KLauncherAdaptor = {
    {
QT_MOC_LITERAL(0, 0, 16), // "KLauncherAdaptor"
QT_MOC_LITERAL(1, 17, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 33, 17), // "org.kde.KLauncher"
QT_MOC_LITERAL(3, 51, 14), // "autoStart0Done"
QT_MOC_LITERAL(4, 66, 0), // ""
QT_MOC_LITERAL(5, 67, 14), // "autoStart1Done"
QT_MOC_LITERAL(6, 82, 14), // "autoStart2Done"
QT_MOC_LITERAL(7, 97, 9), // "autoStart"
QT_MOC_LITERAL(8, 107, 5), // "phase"
QT_MOC_LITERAL(9, 113, 10), // "exec_blind"
QT_MOC_LITERAL(10, 124, 4), // "name"
QT_MOC_LITERAL(11, 129, 8), // "arg_list"
QT_MOC_LITERAL(12, 138, 4), // "envs"
QT_MOC_LITERAL(13, 143, 10), // "startup_id"
QT_MOC_LITERAL(14, 154, 12), // "kdeinit_exec"
QT_MOC_LITERAL(15, 167, 3), // "app"
QT_MOC_LITERAL(16, 171, 4), // "args"
QT_MOC_LITERAL(17, 176, 3), // "env"
QT_MOC_LITERAL(18, 180, 12), // "QDBusMessage"
QT_MOC_LITERAL(19, 193, 3), // "msg"
QT_MOC_LITERAL(20, 197, 8), // "QString&"
QT_MOC_LITERAL(21, 206, 15), // "dbusServiceName"
QT_MOC_LITERAL(22, 222, 5), // "error"
QT_MOC_LITERAL(23, 228, 4), // "int&"
QT_MOC_LITERAL(24, 233, 3), // "pid"
QT_MOC_LITERAL(25, 237, 17), // "kdeinit_exec_wait"
QT_MOC_LITERAL(26, 255, 25), // "kdeinit_exec_with_workdir"
QT_MOC_LITERAL(27, 281, 7), // "workdir"
QT_MOC_LITERAL(28, 289, 20), // "reparseConfiguration"
QT_MOC_LITERAL(29, 310, 12), // "setLaunchEnv"
QT_MOC_LITERAL(30, 323, 5), // "value"
QT_MOC_LITERAL(31, 329, 29), // "start_service_by_desktop_name"
QT_MOC_LITERAL(32, 359, 11), // "serviceName"
QT_MOC_LITERAL(33, 371, 4), // "urls"
QT_MOC_LITERAL(34, 376, 5), // "blind"
QT_MOC_LITERAL(35, 382, 29), // "start_service_by_desktop_path"
QT_MOC_LITERAL(36, 412, 17) // "terminate_kdeinit"

    },
    "KLauncherAdaptor\0D-Bus Interface\0"
    "org.kde.KLauncher\0autoStart0Done\0\0"
    "autoStart1Done\0autoStart2Done\0autoStart\0"
    "phase\0exec_blind\0name\0arg_list\0envs\0"
    "startup_id\0kdeinit_exec\0app\0args\0env\0"
    "QDBusMessage\0msg\0QString&\0dbusServiceName\0"
    "error\0int&\0pid\0kdeinit_exec_wait\0"
    "kdeinit_exec_with_workdir\0workdir\0"
    "reparseConfiguration\0setLaunchEnv\0"
    "value\0start_service_by_desktop_name\0"
    "serviceName\0urls\0blind\0"
    "start_service_by_desktop_path\0"
    "terminate_kdeinit"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KLauncherAdaptor[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
      15,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,   91,    4, 0x06 /* Public */,
       5,    0,   92,    4, 0x06 /* Public */,
       6,    0,   93,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,   94,    4, 0x0a /* Public */,
       7,    0,   97,    4, 0x2a /* Public | MethodCloned */,
       9,    2,   98,    4, 0x0a /* Public */,
       9,    4,  103,    4, 0x0a /* Public */,
      14,    8,  112,    4, 0x0a /* Public */,
      25,    8,  129,    4, 0x0a /* Public */,
      26,    9,  146,    4, 0x0a /* Public */,
      28,    0,  165,    4, 0x0a /* Public */,
      29,    2,  166,    4, 0x0a /* Public */,
      31,    9,  171,    4, 0x0a /* Public */,
      35,    9,  190,    4, 0x0a /* Public */,
      36,    0,  209,    4, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,   10,   11,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList, QMetaType::QStringList, QMetaType::QString,   10,   11,   12,   13,
    QMetaType::Int, QMetaType::QString, QMetaType::QStringList, QMetaType::QStringList, QMetaType::QString, 0x80000000 | 18, 0x80000000 | 20, 0x80000000 | 20, 0x80000000 | 23,   15,   16,   17,   13,   19,   21,   22,   24,
    QMetaType::Int, QMetaType::QString, QMetaType::QStringList, QMetaType::QStringList, QMetaType::QString, 0x80000000 | 18, 0x80000000 | 20, 0x80000000 | 20, 0x80000000 | 23,   15,   16,   17,   13,   19,   21,   22,   24,
    QMetaType::Int, QMetaType::QString, QMetaType::QStringList, QMetaType::QString, QMetaType::QStringList, QMetaType::QString, 0x80000000 | 18, 0x80000000 | 20, 0x80000000 | 20, 0x80000000 | 23,   15,   16,   27,   17,   13,   19,   21,   22,   24,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   10,   30,
    QMetaType::Int, QMetaType::QString, QMetaType::QStringList, QMetaType::QStringList, QMetaType::QString, QMetaType::Bool, 0x80000000 | 18, 0x80000000 | 20, 0x80000000 | 20, 0x80000000 | 23,   32,   33,   12,   13,   34,   19,   21,   22,   24,
    QMetaType::Int, QMetaType::QString, QMetaType::QStringList, QMetaType::QStringList, QMetaType::QString, QMetaType::Bool, 0x80000000 | 18, 0x80000000 | 20, 0x80000000 | 20, 0x80000000 | 23,   32,   33,   12,   13,   34,   19,   21,   22,   24,
    QMetaType::Void,

       0        // eod
};

void KLauncherAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KLauncherAdaptor *_t = static_cast<KLauncherAdaptor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->autoStart0Done(); break;
        case 1: _t->autoStart1Done(); break;
        case 2: _t->autoStart2Done(); break;
        case 3: _t->autoStart((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->autoStart(); break;
        case 5: _t->exec_blind((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 6: _t->exec_blind((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< const QStringList(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 7: { int _r = _t->kdeinit_exec((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< const QStringList(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QDBusMessage(*)>(_a[5])),(*reinterpret_cast< QString(*)>(_a[6])),(*reinterpret_cast< QString(*)>(_a[7])),(*reinterpret_cast< int(*)>(_a[8])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 8: { int _r = _t->kdeinit_exec_wait((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< const QStringList(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QDBusMessage(*)>(_a[5])),(*reinterpret_cast< QString(*)>(_a[6])),(*reinterpret_cast< QString(*)>(_a[7])),(*reinterpret_cast< int(*)>(_a[8])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->kdeinit_exec_with_workdir((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QStringList(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QDBusMessage(*)>(_a[6])),(*reinterpret_cast< QString(*)>(_a[7])),(*reinterpret_cast< QString(*)>(_a[8])),(*reinterpret_cast< int(*)>(_a[9])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->reparseConfiguration(); break;
        case 11: _t->setLaunchEnv((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 12: { int _r = _t->start_service_by_desktop_name((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< const QStringList(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< const QDBusMessage(*)>(_a[6])),(*reinterpret_cast< QString(*)>(_a[7])),(*reinterpret_cast< QString(*)>(_a[8])),(*reinterpret_cast< int(*)>(_a[9])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 13: { int _r = _t->start_service_by_desktop_path((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< const QStringList(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< const QDBusMessage(*)>(_a[6])),(*reinterpret_cast< QString(*)>(_a[7])),(*reinterpret_cast< QString(*)>(_a[8])),(*reinterpret_cast< int(*)>(_a[9])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->terminate_kdeinit(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 4:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusMessage >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 4:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusMessage >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 5:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusMessage >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 5:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusMessage >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 5:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusMessage >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KLauncherAdaptor::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLauncherAdaptor::autoStart0Done)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KLauncherAdaptor::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLauncherAdaptor::autoStart1Done)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KLauncherAdaptor::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KLauncherAdaptor::autoStart2Done)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KLauncherAdaptor::staticMetaObject = {
    { &QDBusAbstractAdaptor::staticMetaObject, qt_meta_stringdata_KLauncherAdaptor.data,
      qt_meta_data_KLauncherAdaptor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KLauncherAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KLauncherAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KLauncherAdaptor.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KLauncherAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void KLauncherAdaptor::autoStart0Done()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KLauncherAdaptor::autoStart1Done()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KLauncherAdaptor::autoStart2Done()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
